--
-- AutoBarProfile
-- Copyright 2007+ Toadkiller of Proudmoore.
--
-- Categories for AutoBar
-- A Category encapsulates a list of items / spells etc. along with metadata describing their use.
-- http://code.google.com/p/autobar/
--

--	PeriodicGroup
--		description
--		texture
--		targetted
--		nonCombat
--		location
--		battleground
--		notUsable (soul shards, arrows, etc.)
--		flying

--	AutoBar
--		arrangeOnUse

--		spell
--		limit


AutoBarCategoryList = {}

local L = AceLibrary("AceLocale-2.2"):new("AutoBar")
local PT = AceLibrary:GetInstance("PeriodicTable-3.0")
local BS = AceLibrary:GetInstance("Babble-Spell-2.2")
local BZ = AceLibrary:GetInstance("Babble-Zone-2.2")
local AceOO = AceLibrary("AceOO-2.0")

-- Mandatory attributes:
--		description - localized description
--		texture - display icon texture
-- Optional attributes:
--		arrangeOnUse, targetted, nonCombat, location, battleground, notUsable
AutoBarCategory = AceOO.Class()
AutoBarCategory.virtual = true -- this means that it cannot be instantiated. (cannot call :new())

function AutoBarCategory.prototype:init(description, texture)
	AutoBarCategory.super.prototype.init(self) -- very important. Will fail without this.
	self.description = L[description]
	self.texture = texture
end

-- True if an item gets arranged to the top on use
function AutoBarCategory.prototype:SetArrangeOnUse(arrangeOnUse)
	self.arrangeOnUse = arrangeOnUse
end

-- Move item to the top (end) of list
function AutoBarCategory.prototype:ArrangeOnUse(item)
-- TODO: arrangeOnUse

end

-- True if items can be targetted
function AutoBarCategory.prototype:SetTargetted(targetted)
	self.targetted = targetted
end

-- True if only usable outside combat
function AutoBarCategory.prototype:SetNonCombat(nonCombat)
	self.nonCombat = nonCombat
end

-- True if item is location specific
function AutoBarCategory.prototype:SetLocation(location)
	self.location = location
end

-- True if item is for battlegrounds only
function AutoBarCategory.prototype:SetBattleground(battleground)
	self.battleground = battleground
end

-- True if item is not usable (soul shards, arrows, etc.)
function AutoBarCategory.prototype:SetNotUsable(notUsable)
	self.notUsable = notUsable
end

-- Top castable item from castList will cast on RightClick
function AutoBarCategory.prototype:SetCastList(castList)
	self.castList = castList
end

-- Called once to allocate space and initialize items
function AutoBarCategory.prototype:ItemsInit()
	self.items = nil
end

-- Reset the item list based on changed settings.
-- So pet change, Spellbook changed for spells, etc.
function AutoBarCategory.prototype:Refresh()
end



-- Category consisting of regular items
AutoBarItems = AceOO.Class(AutoBarCategory)

-- ptItems, ptPriorityItems are PeriodicTable sets
-- priorityItems sort higher than items at the same value
function AutoBarItems.prototype:init(description, texture, ptItems, ptPriorityItems)
	AutoBarItems.super.prototype.init(self, description, texture) -- very important. Will fail without this.
	self.ptItems = ptItems
	self.ptPriorityItems = ptPriorityItems

	local rawList = nil
	rawList = AutoBarCategoryList:RawItemsAdd(rawList, ptItems, false)
	if (ptPriorityItems) then
		rawList = AutoBarCategoryList:RawItemsAdd(rawList, ptPriorityItems, true)
	end
	self.items = AutoBarCategoryList:RawItemsConvert(rawList)
end

-- Reset the item list based on changed settings.
function AutoBarItems.prototype:Refresh()
end



-- Category consisting of spells
AutoBarSpells = AceOO.Class(AutoBarCategory)

-- castList, rightClickList are of the form:
-- { "DRUID", BS["Flight Form"], "DRUID", BS["Swift Flight Form"], ["<class>", "<localized spell name>",] ... }
-- If present rightClickList overrides rightClick spell forcing no action if not present
-- # rightClickList <= # castList per class
-- Icon from castList is used unless not available but rightClickList is
function AutoBarSpells.prototype:init(description, texture, castList, rightClickList)
	AutoBarSpells.super.prototype.init(self, description, texture) -- very important. Will fail without this.
	local castList, spellName, spellList, index

	-- Filter out CLASS spells from castList
	index = 1
	for i = 1, # castList, 2 do
		if (AutoBarProfile.CLASS == castList[i]) then
			spellName = castList[i + 1]
			AutoBarSearch.spells[spellName] = false
			if (not self.castList) then
				self.castList = {}
			end
			self.castList[index] = spellName
			index = index + 1
		end
	end

	-- Filter out CLASS spells from rightClickList
	index = 1
	for i = 1, # rightClickList, 2 do
		if (AutoBarProfile.CLASS == rightClickList[i]) then
			spellName = rightClickList[i + 1]
			AutoBarSearch.spells[spellName] = false
			if (not self.rightClickList) then
				self.rightClickList = {}
			end
			self.rightClickList[index] = spellName
			index = index + 1
		end
	end

	-- Populate items based on currently castable spells
	index = 1
	self.items = {}
	if (self.castList) then
		for i, spellName in ipairs(self.castList) do
			AutoBarSearch:RegisterSpell(spellName)
			if (AutoBarSearch:CanCastSpell(spellName)) then	-- TODO: update on leveling in case new spell aquired
--DEFAULT_CHAT_FRAME:AddMessage("AutoBarSpells.prototype:init castable " .. tostring(spellName))
				self.items[index] = spellName
				index = index + 1
			end
		end
	end

--		spellList = {}
--		spellList[1] = self:RegisterSpell(BS["Teleport: Moonglade"])
--		self.items = spellList
end

-- Reset the item list based on changed settings.
function AutoBarSpells.prototype:Refresh()
end












local function sortList(a, b)
	local x = tonumber(a[2]);
	local y = tonumber(b[2]);

	if (x == y) then
		if (a[3]) then
			return false;
		else
			if (b[3]) then
				return true;
			else
				return false;
			end
		end
	else
		return x < y;
	end
end


-- Get set as a simple array of itemIds, ordered by their value in the set
-- If provided, also record the values scaled by downFactor into downHp, downMana
function AutoBarCategoryList:GetSetItemsArrayPT3(set, downHp, downMana, downFactor)
	local itemArray = {};
	local cacheSet = PT:GetSetTable(set);
	if (cacheSet) then
		local sortedList = {};
		local index = 1;
		for itemId, value in PT:IterateSet(set) do
			if (type(value) == "boolean") then
				value = 0;
			end
			sortedList[index] = { itemId, value };
			index = index + 1;
		end
		table.sort(sortedList, sortList);
		for i, j in ipairs(sortedList) do
			itemArray[i] = j[1];
			if (downHp) then
				downHp[i] = j[2] * downFactor;
			end
			if (downMana) then
				downMana[i] = j[2]* downFactor;
			end
		end
	end
	return itemArray;
end


-- Convert rawList to a simple array of itemIds, ordered by their value in the set, and priority if any
-- If provided, also record the values scaled by downFactor into downHp, downMana
function AutoBarCategoryList:RawItemsConvert(rawList, downHp, downMana, downFactor)
	local itemArray = {};
	table.sort(rawList, sortList);
	for i, j in ipairs(rawList) do
		itemArray[i] = j[1];
		if (downHp) then
			downHp[i] = j[2] * downFactor;
		end
		if (downMana) then
			downMana[i] = j[2]* downFactor;
		end
	end
	return itemArray;
end


-- Add items from set to rawList
-- If priority is true, the items will have priority over non-priority items with the same values
function AutoBarCategoryList:RawItemsAdd(rawList, set, priority)
--DEFAULT_CHAT_FRAME:AddMessage("RawItemsAdd set " .. tostring(set).." priority ".. tostring(priority));
	if (not rawList) then
		rawList = {};
	end
	local cacheSet = PT:GetSetTable(set);
	if (cacheSet) then
		local index = table.getn(rawList) + 1;
		for itemId, value in PT:IterateSet(set) do
			if (not value or type(value) == "boolean") then
				value = 0;
			end
			value = tonumber(value);
			rawList[index] = {itemId, value, priority};
			index = index + 1;
		end
	end
	return rawList;
end


-- Fill in category item lists with the raw data from PeriodicTable.
-- Unless AutoBar is drastically restructured thats the most use we can get from PeriodicTable
function AutoBarCategoryList:Initialize()
--	Misc.Hearth
--	["HEARTHSTONE"] = {
--		["description"] = Misc.Hearth;
--		["texture"] = "INV_Misc_Rune_01";
--		["items"] = {
--			6948,			-- HearthStone
--		},
--	},
	AutoBar_Category_Info["HEARTHSTONE"] = AutoBarItems:new(
			"Misc.Hearth", "INV_Misc_Rune_01", "Misc.Hearth")

--	["ACTION_POTIONS"] = {
--		["description"] = Consumable.Buff.Free Action; -- Consumable.Buff.Free Action
--		["texture"] = "INV_Potion_04";
--		["items"] = {
--			20008,		-- Living Action Potion
--			5634,		-- Free Action Potion
--		},
--	},
	AutoBar_Category_Info["Consumable.Buff.Free Action"] = AutoBarItems:new(
			"Consumable.Buff.Free Action", "INV_Potion_04", "Consumable.Buff.Free Action")

--	AutoBar_Category_Info["ANTI_VENOM"]["items"] = self:GetSetItemsArrayPT3("Consumable.Anti-Venom");
--	["ANTI_VENOM"] = {
--		["description"] = Consumable.Anti-Venom;
--		["texture"] = "INV_Drink_14";
--		["targetted"] = true;
--	},
	AutoBar_Category_Info["ANTI_VENOM"] = AutoBarItems:new(
			"Consumable.Anti-Venom", "INV_Drink_14", "Consumable.Anti-Venom")
	AutoBar_Category_Info["ANTI_VENOM"]:SetTargetted(true)

--	["BATTLE_STANDARD"] = {
--		["description"] = Misc.Battle Standard.Battleground; Misc.Battle Standard.Battleground
--		["texture"] = "INV_BannerPVP_01";
--		["battleground"] = true;
--		["items"] = {
--			18606,	-- Alliance Battle Standard
--			18607,	-- Horde Battle Standard
--		},
--	},
	AutoBar_Category_Info["BATTLE_STANDARD"] = AutoBarItems:new(
			"Misc.Battle Standard.Battleground", "INV_BannerPVP_01", "Misc.Battle Standard.Battleground")
	AutoBar_Category_Info["BATTLE_STANDARD"]:SetBattleground(true)

--	["BATTLE_STANDARD_AV"] = {
--		["description"] = Misc.Battle Standard.Alterac Valley; Misc.Battle Standard.Alterac Valley
--		["texture"] = "INV_BannerPVP_02";
--		["location"] = AUTOBAR_ALTERACVALLEY;
--		["items"] = {
--			19045,	-- Stormpike Battle Standard
--			19046,	-- Frostwolf Battle Standard
--		},
--	},
	AutoBar_Category_Info["BATTLE_STANDARD_AV"] = AutoBarItems:new(
			"Misc.Battle Standard.Alterac Valley", "INV_BannerPVP_02", "Misc.Battle Standard.Alterac Valley")
	AutoBar_Category_Info["BATTLE_STANDARD_AV"]:SetLocation(BZ["Alterac Valley"])

--	AutoBar_Category_Info["ARROWS"]["items"] = self:GetSetItemsArrayPT3("Reagent.Ammo.Arrow");
--	["ARROWS"] = {
--		["description"] = Reagent.Ammo.Arrow;
--		["texture"] = "INV_Ammo_Arrow_02";
--		["notUsable"] = true;
--	},
	AutoBar_Category_Info["ARROWS"] = AutoBarItems:new(
			"Reagent.Ammo.Arrow", "INV_Ammo_Arrow_02", "Reagent.Ammo.Arrow")
	AutoBar_Category_Info["ARROWS"]:SetNotUsable(true)

--	AutoBar_Category_Info["BULLETS"]["items"] = self:GetSetItemsArrayPT3("Reagent.Ammo.Bullet");
--	["BULLETS"] = {
--		["description"] = Reagent.Ammo.Bullet;
--		["texture"] = "INV_Ammo_Bullet_02";
--		["notUsable"] = true;
--	},
	AutoBar_Category_Info["BULLETS"] = AutoBarItems:new(
			"Reagent.Ammo.Bullet", "INV_Ammo_Bullet_02", "Reagent.Ammo.Bullet")
	AutoBar_Category_Info["BULLETS"]:SetNotUsable(true)

--	AutoBar_Category_Info["THROWN"]["items"] = self:GetSetItemsArrayPT3("Reagent.Ammo.Thrown");
--	["THROWN"] = {
--		["description"] = Reagent.Ammo.Thrown;
--		["texture"] = "INV_Axe_19";
--		["notUsable"] = true;
--	},
	AutoBar_Category_Info["THROWN"] = AutoBarItems:new(
			"Reagent.Ammo.Thrown", "INV_Axe_19", "Reagent.Ammo.Thrown")
	AutoBar_Category_Info["THROWN"]:SetNotUsable(true)

--	AutoBar_Category_Info["EXPLOSIVES"]["items"] = self:GetSetItemsArrayPT3("Misc.Engineering.Explosives");
--	["EXPLOSIVES"] = {
--		["description"] = Misc.Engineering.Explosives;
--		["texture"] = "INV_Misc_Bomb_08";
--		["targetted"] = true;
--	},
	AutoBar_Category_Info["EXPLOSIVES"] = AutoBarItems:new(
			"Misc.Engineering.Explosives", "INV_Misc_Bomb_08", "Misc.Engineering.Explosives")
	AutoBar_Category_Info["EXPLOSIVES"]:SetTargetted(true)

--	["Misc.Engineering.Fireworks"] = {
--		["description"] = L["Misc.Engineering.Fireworks"];
--		["texture"] = "INV_Misc_MissileSmall_Red";
--		["arrangeOnUse"] = true,
--	},
	AutoBar_Category_Info["Misc.Engineering.Fireworks"] = AutoBarItems:new(
			"Misc.Engineering.Fireworks", "INV_Misc_MissileSmall_Red", "Misc.Engineering.Fireworks")
	AutoBar_Category_Info["Misc.Engineering.Fireworks"]:SetArrangeOnUse(true)

--	AutoBar_Category_Info["Tradeskill.Tool.Fishing.Gear"]["items"] = self:GetSetItemsArrayPT3("Tradeskill.Tool.Fishing.Gear");
--	["FISHING_GEAR"] = {
--		["texture"] = "INV_Helmet_31",
--		["description"] = L["Tradeskill.Tool.Fishing.Gear"],
--	},
	AutoBar_Category_Info["Tradeskill.Tool.Fishing.Gear"] = AutoBarItems:new(
			"Tradeskill.Tool.Fishing.Gear", "INV_Helmet_31", "Tradeskill.Tool.Fishing.Gear")

--	AutoBar_Category_Info["Tradeskill.Tool.Fishing.Lure"]["items"] = self:GetSetItemsArrayPT3("Tradeskill.Tool.Fishing.Lure");
--	["FISHING_LURES"] = {
--		["texture"] = "INV_Misc_Food_26",
--		["targetted"] = "WEAPON",
--		["description"] = L["Tradeskill.Tool.Fishing.Lure"],
--	},
	AutoBar_Category_Info["Tradeskill.Tool.Fishing.Lure"] = AutoBarItems:new(
			"Tradeskill.Tool.Fishing.Lure", "INV_Misc_Food_26", "Tradeskill.Tool.Fishing.Lure")
	AutoBar_Category_Info["Tradeskill.Tool.Fishing.Lure"]:SetTargetted("WEAPON")

--	AutoBar_Category_Info["Tradeskill.Tool.Fishing.Tool"]["items"] = self:GetSetItemsArrayPT3("Tradeskill.Tool.Fishing.Tool");
--	["FISHING_POLES"] = {
--		["texture"] = "INV_Fishingpole_01",
--		["description"] = L["Tradeskill.Tool.Fishing.Tool"],
--	},
	AutoBar_Category_Info["INV_Fishingpole_01"] = AutoBarItems:new(
			"Tradeskill.Tool.Fishing.Tool", "INV_Fishingpole_01", "Tradeskill.Tool.Fishing.Tool")

--	["RUNES"] = {
--		["description"] = Consumable.Recovery.Rune; Consumable.Recovery.Rune
--		["texture"] = "Spell_Shadow_SealOfKings";
--		["items"] = {
--			20520,	-- Dark Rune
--			12662,	-- Demonic Rune
--		},
--	},
	AutoBar_Category_Info["RUNES"] = AutoBarItems:new(
			"Consumable.Recovery.Rune", "Spell_Shadow_SealOfKings", "Consumable.Recovery.Rune")


--	AutoBar_Category_Info["BANDAGES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Bandage.Basic");
--	["BANDAGES"] = {
--		["description"] = Consumable.Bandage.Basic;
--		["texture"] = "INV_Misc_Bandage_Netherweave_Heavy";
--		["targetted"] = true;
--	},
	AutoBar_Category_Info["BANDAGES"] = AutoBarItems:new(
			"Consumable.Bandage.Basic", "INV_Misc_Bandage_Netherweave_Heavy", "Consumable.Bandage.Basic")
	AutoBar_Category_Info["BANDAGES"]:SetTargetted(true)

--	AutoBar_Category_Info["ALTERAC_BANDAGES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Bandage.Battleground.Alterac Valley");
--	["ALTERAC_BANDAGES"] = {
--		["description"] = Consumable.Bandage.Battleground.Alterac Valley;
--		["texture"] = "INV_Misc_Bandage_12";
--		["targetted"] = true;
--		["location"] = AUTOBAR_ALTERACVALLEY;
--	},
	AutoBar_Category_Info["ALTERAC_BANDAGES"] = AutoBarItems:new(
			"Consumable.Bandage.Battleground.Alterac Valley", "INV_Misc_Bandage_12", "Consumable.Bandage.Battleground.Alterac Valley")
	AutoBar_Category_Info["ALTERAC_BANDAGES"]:SetTargetted(true)
	AutoBar_Category_Info["ALTERAC_BANDAGES"]:SetLocation(BZ["Alterac Valley"])

--	AutoBar_Category_Info["ARATHI_BANDAGES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Bandage.Battleground.Arathi Basin");
--	["ARATHI_BANDAGES"] = {
--		["description"] = Consumable.Bandage.Battleground.Arathi Basin;
--		["texture"] = "INV_Misc_Bandage_12";
--		["targetted"] = true;
--		["location"] = AUTOBAR_ARATHIBASIN;
--	},
	AutoBar_Category_Info["ARATHI_BANDAGES"] = AutoBarItems:new(
			"Consumable.Bandage.Battleground.Arathi Basin", "INV_Misc_Bandage_12", "Consumable.Bandage.Battleground.Arathi Basin")
	AutoBar_Category_Info["ARATHI_BANDAGES"]:SetTargetted(true)
	AutoBar_Category_Info["ARATHI_BANDAGES"]:SetLocation(BZ["Arathi Basin"])

--	AutoBar_Category_Info["WARSONG_BANDAGES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Bandage.Battleground.Warsong Gulch");
--	["WARSONG_BANDAGES"] = {
--		["description"] = Consumable.Bandage.Battleground.Warsong Gulch;
--		["texture"] = "INV_Misc_Bandage_12";
--		["targetted"] = true;
--		["location"] = AUTOBAR_WARSONGGULCH;
--	},
	AutoBar_Category_Info["WARSONG_BANDAGES"] = AutoBarItems:new(
			"Consumable.Bandage.Battleground.Warsong Gulch", "INV_Misc_Bandage_12", "Consumable.Bandage.Battleground.Warsong Gulch")
	AutoBar_Category_Info["WARSONG_BANDAGES"]:SetTargetted(true)
	AutoBar_Category_Info["WARSONG_BANDAGES"]:SetLocation(BZ["Warsong Gulch"])

--	AutoBar_Category_Info["FOOD"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Basic.Non-Conjured");
--	["FOOD"] = {
--		["description"] = Consumable.Food.Edible.Basic.Non-Conjured;
--		["texture"] = "INV_Misc_Food_23";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD"] = AutoBarItems:new(
			"Consumable.Food.Edible.Basic.Non-Conjured", "INV_Misc_Food_23", "Consumable.Food.Edible.Basic.Non-Conjured")
	AutoBar_Category_Info["FOOD"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_ARATHI"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Battleground.Arathi Basin.Basic");
--	["FOOD_ARATHI"] = {
--		["description"] = Consumable.Food.Edible.Battleground.Arathi Basin.Basic;
--		["texture"] = "INV_Misc_Food_33";
--		["nonCombat"] = true,
--		["location"] = AUTOBAR_ARATHIBASIN;
--	},
	AutoBar_Category_Info["FOOD_ARATHI"] = AutoBarItems:new(
			"Consumable.Food.Edible.Battleground.Arathi Basin.Basic", "INV_Misc_Food_33", "Consumable.Food.Edible.Battleground.Arathi Basin.Basic")
	AutoBar_Category_Info["FOOD_ARATHI"]:SetNonCombat(true)
	AutoBar_Category_Info["FOOD_ARATHI"]:SetLocation(BZ["Arathi Basin"])

--	AutoBar_Category_Info["FOOD_WARSONG"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Battleground.Warsong Gulch.Basic");
--	["FOOD_WARSONG"] = {
--		["description"] = Consumable.Food.Edible.Battleground.Warsong Gulch.Basic;
--		["texture"] = "INV_Misc_Food_33";
--		["nonCombat"] = true,
--		["location"] = AUTOBAR_WARSONGGULCH;
--	},
	AutoBar_Category_Info["FOOD_WARSONG"] = AutoBarItems:new(
			"Consumable.Food.Edible.Battleground.Warsong Gulch.Basic", "INV_Misc_Food_33", "Consumable.Food.Edible.Battleground.Warsong Gulch.Basic")
	AutoBar_Category_Info["FOOD_WARSONG"]:SetNonCombat(true)
	AutoBar_Category_Info["FOOD_WARSONG"]:SetLocation(BZ["Warsong Gulch"])

--	AutoBar_Category_Info["FOOD_COMBO"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Combo Health");
--	["FOOD_COMBO"] = {
--		["description"] = Consumable.Food.Combo Health;
--		["texture"] = "INV_Misc_Food_33";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_COMBO"] = AutoBarItems:new(
			"Consumable.Food.Combo Health", "INV_Misc_Food_33", "Consumable.Food.Combo Health")
	AutoBar_Category_Info["FOOD_COMBO"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_CONJURED"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Bread.Conjured");
--	["FOOD_CONJURED"] = {
--		["description"] = Consumable.Food.Edible.Bread.Conjured;
--		["texture"] = "INV_Misc_Food_73CinnamonRoll";
--		["nonCombat"] = true,
--		["castList"] = {"MAGE", BS["Conjure Food"],},
--	},
	AutoBar_Category_Info["FOOD_CONJURED"] = AutoBarItems:new(
			"Consumable.Food.Edible.Bread.Conjured", "INV_Misc_Food_73CinnamonRoll", "Consumable.Food.Edible.Bread.Conjured")
	AutoBar_Category_Info["FOOD_CONJURED"]:SetNonCombat(true)
	AutoBar_Category_Info["FOOD_CONJURED"]:SetCastList({"MAGE", BS["Conjure Food"],})

--	AutoBar_Category_Info["FOOD_PERCENT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Percent.Basic");
--	["FOOD_PERCENT"] = {
--		["description"] = Consumable.Food.Percent.Basic;
--		["texture"] = "INV_Misc_Food_60",
--	},
	AutoBar_Category_Info["FOOD_PERCENT"] = AutoBarItems:new(
			"Consumable.Food.Percent.Basic", "INV_Misc_Food_60", "Consumable.Food.Percent.Basic")
	AutoBar_Category_Info["FOOD_PERCENT"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_PERCENT_BONUS"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Percent.Bonus");
--	["FOOD_PERCENT_BONUS"] = {
--		["description"] = Consumable.Food.Percent.Bonus;
--		["texture"] = "INV_Misc_Food_62",
--	},
	AutoBar_Category_Info["FOOD_PERCENT_BONUS"] = AutoBarItems:new(
			"Consumable.Food.Percent.Bonus", "INV_Misc_Food_62", "Consumable.Food.Percent.Bonus")
	AutoBar_Category_Info["FOOD_PERCENT_BONUS"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_PERCENT_COMBO"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Combo Percent");
--	["FOOD_PERCENT_COMBO"] = {
--		["description"] = Consumable.Food.Combo Percent;
--		["texture"] = "INV_Food_ChristmasFruitCake_01",
--	},
	AutoBar_Category_Info["FOOD_PERCENT_COMBO"] = AutoBarItems:new(
			"Consumable.Food.Combo Percent", "INV_Food_ChristmasFruitCake_01", "Consumable.Food.Combo Percent")
	AutoBar_Category_Info["FOOD_PERCENT_COMBO"]:SetNonCombat(true)

----	rawList = self:RawItemsAdd(nil, "Consumable.Food.Edible.Bread.Basic", false);
----	rawList = self:RawItemsAdd(rawList, "Consumable.Food.Edible.Bread.Conjured", true);
----	AutoBar_Category_Info["FOOD_PET_BREAD"]["items"] = self:RawItemsConvert(rawList);
----	["FOOD_PET_BREAD"] = {
----		["description"] = Consumable.Food.Edible.Basic.Non-Conjured_PET_BREAD;
----		["texture"] = "INV_Misc_Food_35";
----		["nonCombat"] = true,
----		["targetted"] = "PET";
----		["castSpell"] = BS["Feed Pet"];
----	},
--	AutoBar_Category_Info["FOOD_PET_BREAD"] = AutoBarItems:new(
--			"Consumable.Food.Edible.Bread.Basic", "INV_Misc_Food_35", "Consumable.Food.Edible.Bread.Basic", "Consumable.Food.Edible.Bread.Conjured")
--	AutoBar_Category_Info["FOOD_PET_BREAD"]:SetNonCombat(true)
--	AutoBar_Category_Info["FOOD_PET_BREAD"]:SetTargetted("PET")
--
----	AutoBar_Category_Info["FOOD_PET_CHEESE"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Cheese.Basic");
----	["FOOD_PET_CHEESE"] = {
----		["description"] = Consumable.Food.Edible.Basic.Non-Conjured_PET_CHEESE;
----		["texture"] = "INV_Misc_Food_37";
----		["nonCombat"] = true,
----		["targetted"] = "PET";
----		["castSpell"] = BS["Feed Pet"];
----	},
--	AutoBar_Category_Info["FOOD_PET_CHEESE"] = AutoBarItems:new(
--			"Consumable.Food.Edible.Cheese.Basic", "INV_Misc_Food_37", "Consumable.Food.Edible.Cheese.Basic")
--	AutoBar_Category_Info["FOOD_PET_CHEESE"]:SetNonCombat(true)
--	AutoBar_Category_Info["FOOD_PET_CHEESE"]:SetTargetted("PET")
--
----	rawList = self:RawItemsAdd(nil, "Consumable.Food.Inedible.Fish", false);
----	rawList = self:RawItemsAdd(rawList, "Consumable.Food.Edible.Fish.Basic", true);
----	AutoBar_Category_Info["FOOD_PET_FISH"]["items"] = self:RawItemsConvert(rawList);
----	["FOOD_PET_FISH"] = {
----		["description"] = Consumable.Food.Edible.Basic.Non-Conjured_PET_FISH;
----		["texture"] = "INV_Misc_Fish_22";
----		["nonCombat"] = true,
----		["targetted"] = "PET";
----		["castSpell"] = BS["Feed Pet"];
----	},
--	AutoBar_Category_Info["FOOD_PET_FISH"] = AutoBarItems:new(
--			"Consumable.Food.Edible.Fish.Basic", "INV_Misc_Fish_22", "Consumable.Food.Inedible.Fish", "Consumable.Food.Edible.Fish.Basic")
--	AutoBar_Category_Info["FOOD_PET_FISH"]:SetNonCombat(true)
--	AutoBar_Category_Info["FOOD_PET_FISH"]:SetTargetted("PET")
--
----	AutoBar_Category_Info["FOOD_PET_FRUIT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Fruit.Basic");
----	["FOOD_PET_FRUIT"] = {
----		["description"] = Consumable.Food.Edible.Basic.Non-Conjured_PET_FRUIT;
----		["texture"] = "INV_Misc_Food_19";
----		["nonCombat"] = true,
----		["targetted"] = "PET";
----		["castSpell"] = BS["Feed Pet"];
----	},
--	AutoBar_Category_Info["FOOD_PET_FRUIT"] = AutoBarItems:new(
--			"Consumable.Food.Edible.Fruit.Basic", "INV_Misc_Food_19", "Consumable.Food.Edible.Fruit.Basic")
--	AutoBar_Category_Info["FOOD_PET_FRUIT"]:SetNonCombat(true)
--	AutoBar_Category_Info["FOOD_PET_FRUIT"]:SetTargetted("PET")
--
----	AutoBar_Category_Info["FOOD_PET_FUNGUS"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Fungus.Basic");	-- Now includes senjin combo ;-(
----	["FOOD_PET_FUNGUS"] = {
----		["description"] = Consumable.Food.Edible.Basic.Non-Conjured_PET_FUNGUS;
----		["texture"] = "INV_Mushroom_05";
----		["nonCombat"] = true,
----		["targetted"] = "PET";
----		["castSpell"] = BS["Feed Pet"];
----	},
--	AutoBar_Category_Info["FOOD_PET_FUNGUS"] = AutoBarItems:new(
--			"Consumable.Food.Edible.Fungus.Basic", "INV_Mushroom_05", "Consumable.Food.Edible.Fungus.Basic")
--	AutoBar_Category_Info["FOOD_PET_FUNGUS"]:SetNonCombat(true)
--	AutoBar_Category_Info["FOOD_PET_FUNGUS"]:SetTargetted("PET")
--
----	rawList = self:RawItemsAdd(nil, "Consumable.Food.Inedible.Meat", false);
----	rawList = self:RawItemsAdd(rawList, "Consumable.Food.Edible.Meat.Basic", true);
----	AutoBar_Category_Info["FOOD_PET_MEAT"]["items"] = self:RawItemsConvert(rawList);
----	["FOOD_PET_MEAT"] = {
----		["description"] = Consumable.Food.Edible.Basic.Non-Conjured_PET_MEAT;
----		["texture"] = "INV_Misc_Food_14";
----		["nonCombat"] = true,
----		["targetted"] = "PET";
----		["castSpell"] = BS["Feed Pet"];
----	},
--	AutoBar_Category_Info["FOOD_PET_MEAT"] = AutoBarItems:new(
--			"Consumable.Food.Inedible.Meat", "INV_", "Consumable.Food.Inedible.Meat", "Consumable.Food.Edible.Meat.Basic")
--	AutoBar_Category_Info["FOOD_PET_MEAT"]:SetNonCombat(true)
--	AutoBar_Category_Info["FOOD_PET_MEAT"]:SetTargetted("PET")

--	AutoBar_Category_Info["FOOD_BUFF"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Bonus");
--	["FOOD_BUFF"] = {
--		["description"] = L["Consumable.Food.Bonus"];
--		["texture"] = "INV_Misc_Food_47";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["Consumable.Food.Bonus"] = AutoBarItems:new(
			"Consumable.Food.Bonus", "INV_Misc_Food_47", "Consumable.Food.Bonus")
	AutoBar_Category_Info["Consumable.Food.Bonus"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_AGILITY"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Agility");
--	["FOOD_AGILITY"] = {
--		["description"] = L["FOOD_AGILITY"];
--		["texture"] = "INV_Misc_Fish_13";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_AGILITY"] = AutoBarItems:new(
			"Consumable.Food.Buff.Agility", "INV_Misc_Fish_13", "Consumable.Food.Buff.Agility")
	AutoBar_Category_Info["FOOD_AGILITY"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_ATTACK_POWER"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Attack Power");
--	["FOOD_ATTACK_POWER"] = {
--		["description"] = L["FOOD_ATTACK_POWER"];
--		["texture"] = "INV_Misc_Fish_13";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_ATTACK_POWER"] = AutoBarItems:new(
			"Consumable.Food.Buff.Attack Power", "INV_Misc_Fish_13", "Consumable.Food.Buff.Attack Power")
	AutoBar_Category_Info["FOOD_ATTACK_POWER"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_HEALING"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Healing");
--	["FOOD_HEALING"] = {
--		["description"] = L["FOOD_HEALING"];
--		["texture"] = "INV_Misc_Fish_13";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_HEALING"] = AutoBarItems:new(
			"Consumable.Food.Buff.Healing", "INV_Misc_Fish_13", "Consumable.Food.Buff.Healing")
	AutoBar_Category_Info["FOOD_HEALING"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_HPREGEN"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.HP Regen");
--	["FOOD_HPREGEN"] = {
--		["description"] = L["FOOD_HPREGEN"];
--		["texture"] = "INV_Misc_Fish_19";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_HPREGEN"] = AutoBarItems:new(
			"Consumable.Food.Buff.HP Regen", "INV_Misc_Fish_19", "Consumable.Food.Buff.HP Regen")
	AutoBar_Category_Info["FOOD_HPREGEN"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_INTELLECT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Intellect");
--	["FOOD_INTELLECT"] = {
--		["description"] = L["FOOD_INTELLECT"];
--		["texture"] = "INV_Misc_Food_63";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_INTELLECT"] = AutoBarItems:new(
			"Consumable.Food.Buff.Intellect", "INV_Misc_Food_63", "Consumable.Food.Buff.Intellect")
	AutoBar_Category_Info["FOOD_INTELLECT"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_MANAREGEN"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Mana Regen");
--	["FOOD_MANAREGEN"] = {
--		["description"] = L["FOOD_MANAREGEN"];
--		["texture"] = "INV_Drink_17";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_MANAREGEN"] = AutoBarItems:new(
			"Consumable.Food.Buff.Mana Regen", "INV_Drink_17", "Consumable.Food.Buff.Mana Regen")
	AutoBar_Category_Info["FOOD_MANAREGEN"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_SPELL_DAMAGE"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Spell Damage");
--	["FOOD_SPELL_DAMAGE"] = {
--		["description"] = L["FOOD_SPELL_DAMAGE"];
--		["texture"] = "INV_Misc_Food_65";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_SPELL_DAMAGE"] = AutoBarItems:new(
			"Consumable.Food.Buff.Spell Damage", "INV_Misc_Food_65", "Consumable.Food.Buff.Spell Damage")
	AutoBar_Category_Info["FOOD_SPELL_DAMAGE"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_SPIRIT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Spirit");
--	["FOOD_SPIRIT"] = {
--		["description"] = L["FOOD_SPIRIT"];
--		["texture"] = "INV_Misc_Fish_03";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_SPIRIT"] = AutoBarItems:new(
			"Consumable.Food.Buff.Spirit", "INV_Misc_Fish_03", "Consumable.Food.Buff.Spirit")
	AutoBar_Category_Info["FOOD_SPIRIT"]:SetNonCombat(true)

--	AutoBar_Category_Info["FOOD_STAMINA"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Stamina");
--	["FOOD_STAMINA"] = {
--		["description"] = L["FOOD_STAMINA"];
--		["texture"] = "INV_Misc_Food_65";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["FOOD_STAMINA"] = AutoBarItems:new(
			"Consumable.Food.Buff.Stamina", "INV_Misc_Food_65", "Consumable.Food.Buff.Stamina")
	AutoBar_Category_Info["FOOD_STAMINA"]:SetNonCombat(true)

--	AutoBar_Category_Info["Consumable.Food.Buff.Strength"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Strength");
--	["Consumable.Food.Buff.Strength"] = {
--		["description"] = L["Consumable.Food.Buff.Strength"];
--		["texture"] = "INV_Misc_Food_41";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["Consumable.Food.Buff.Strength"] = AutoBarItems:new(
			"Consumable.Food.Buff.Strength", "INV_Misc_Food_41", "Consumable.Food.Buff.Strength")
	AutoBar_Category_Info["Consumable.Food.Buff.Strength"]:SetNonCombat(true)

--
--	AutoBar_Category_Info["Consumable.Food.Buff.Other"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Other");
--	["Consumable.Food.Buff.Other"] = {
--		["description"] = L["Consumable.Food.Buff.Other"];
--		["texture"] = "INV_Drink_17";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["Consumable.Food.Buff.Other"] = AutoBarItems:new(
			"Consumable.Food.Buff.Other", "INV_Drink_17", "Consumable.Food.Buff.Other")
	AutoBar_Category_Info["Consumable.Food.Buff.Other"]:SetNonCombat(true)


	AutoBar_Category_Info["HEALPOTIONS"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.Basic", "INV_Potion_54", "Consumable.Potion.Recovery.Healing.Basic")

	AutoBar_Category_Info["HEALPOTIONS_BG"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.PvP", "INV_Potion_39", "Consumable.Potion.Recovery.Healing.PvP")
	AutoBar_Category_Info["HEALPOTIONS_BG"]:SetBattleground(true)

	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Blades Edge"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.Blades Edge", "INV_Potion_167", "Consumable.Potion.Recovery.Healing.Blades Edge")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Blades Edge"]:SetLocation(BZ["Blade's Edge Mountains"])

	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Coilfang"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.Coilfang", "INV_Potion_167", "Consumable.Potion.Recovery.Healing.Coilfang")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Coilfang"]:SetLocation("Coilfang")

	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Tempest Keep"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.Tempest Keep", "INV_Potion_153", "Consumable.Potion.Recovery.Healing.Tempest Keep")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Tempest Keep"]:SetLocation("Tempest Keep")

	AutoBar_Category_Info["MANAPOTIONS"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Basic", "INV_Potion_76", "Consumable.Potion.Recovery.Mana.Basic")

	AutoBar_Category_Info["MANAPOTIONS_BG"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Pvp", "INV_Potion_81", "Consumable.Potion.Recovery.Mana.Pvp")
	AutoBar_Category_Info["MANAPOTIONS_BG"]:SetBattleground(true)

	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Blades Edge"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Blades Edge", "INV_Potion_168", "Consumable.Potion.Recovery.Mana.Blades Edge")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Blades Edge"]:SetLocation(BZ["Blade's Edge Mountains"])

	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Coilfang"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Coilfang", "INV_Potion_168", "Consumable.Potion.Recovery.Mana.Coilfang")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Coilfang"]:SetLocation("Coilfang")

	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Tempest Keep"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Tempest Keep", "INV_Potion_156", "Consumable.Potion.Recovery.Mana.Tempest Keep")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Tempest Keep"]:SetLocation("Tempest Keep")

--	AutoBar_Category_Info["HEALTHSTONE"]["items"] = self:GetSetItemsArrayPT3("Consumable.Warlock.Healthstone");
--	["HEALTHSTONE"] = {
--		["description"] = Consumable.Warlock.Healthstone;
--		["texture"] = "INV_Stone_04";
--	},
	AutoBar_Category_Info["HEALTHSTONE"] = AutoBarItems:new(
			"Consumable.Warlock.Healthstone", "INV_Stone_04", "Consumable.Warlock.Healthstone")

--	AutoBar_Category_Info["MINI_PET"]["items"] = self:GetSetItemsArrayPT3("Misc.Minipet.Normal");
--	["MINI_PET"] = {
--		["description"] = Misc.Minipet.Normal;
--		["texture"] = "Ability_Creature_Poison_05";
--		["arrangeOnUse"] = true,
--	},
	AutoBar_Category_Info["MINI_PET"] = AutoBarItems:new(
			"Misc.Minipet.Normal", "Ability_Creature_Poison_05", "Misc.Minipet.Normal")
	AutoBar_Category_Info["MINI_PET"]:SetArrangeOnUse(true)

--	AutoBar_Category_Info["MINI_PET_HOLIDAY"]["items"] = self:GetSetItemsArrayPT3("Misc.Minipet.Snowball");
--	["MINI_PET_HOLIDAY"] = {
--		["description"] = Misc.Minipet.Snowball;
--		["texture"] = "INV_Misc_Bag_17";
--		["arrangeOnUse"] = true,
--	},
	AutoBar_Category_Info["MINI_PET_HOLIDAY"] = AutoBarItems:new(
			"Misc.Minipet.Snowball", "INV_Misc_Bag_17", "Misc.Minipet.Snowball")
	AutoBar_Category_Info["MINI_PET_HOLIDAY"]:SetArrangeOnUse(true)

--	AutoBar_Category_Info["MOUNTS"]["items"] = self:GetSetItemsArrayPT3("Misc.Mount.Normal");
--	["MOUNTS"] = {
--		["description"] = Misc.Mount.Normal;
--		["texture"] = "Ability_Mount_JungleTiger";
--		["nonCombat"] = true,
--		["arrangeOnUse"] = true,
--	},
	AutoBar_Category_Info["MOUNTS"] = AutoBarItems:new(
			"Misc.Mount.Normal", "Ability_Mount_JungleTiger", "Misc.Mount.Normal")
	AutoBar_Category_Info["MOUNTS"]:SetNonCombat(true)
	AutoBar_Category_Info["MOUNTS"]:SetArrangeOnUse(true)

--	AutoBar_Category_Info["MOUNTS_QIRAJI"]["items"] = self:GetSetItemsArrayPT3("Misc.Mount.Ahn'Qiraj");
--	["MOUNTS_QIRAJI"] = {
--		["description"] = Misc.Mount.Ahn'Qiraj;
--		["texture"] = "INV_Misc_QirajiCrystal_05";
--		["nonCombat"] = true,
--		["arrangeOnUse"] = true,
--		["location"] = AUTOBAR_AHN_QIRAJ;
--	},
	AutoBar_Category_Info["MOUNTS_QIRAJI"] = AutoBarItems:new(
			"Misc.Mount.Ahn'Qiraj", "INV_Misc_QirajiCrystal_05", "Misc.Mount.Ahn'Qiraj")
	AutoBar_Category_Info["MOUNTS_QIRAJI"]:SetNonCombat(true)
	AutoBar_Category_Info["MOUNTS_QIRAJI"]:SetArrangeOnUse(true)
	AutoBar_Category_Info["MOUNTS_QIRAJI"]:SetLocation(BZ["Ahn'Qiraj"])

--	AutoBar_Category_Info["MOUNTS_FLYING"]["items"] = self:GetSetItemsArrayPT3("Misc.Mount.Flying");
--	["MOUNTS_FLYING"] = {
--		["description"] = Misc.Mount.Flying;
--		["texture"] = "Ability_Mount_Wyvern_01";
--		["nonCombat"] = true,
--		["arrangeOnUse"] = true,
----		["location"] = AUTOBAR_OUTLAND;  TODO: can fly check
--	},
	AutoBar_Category_Info["MOUNTS_FLYING"] = AutoBarItems:new(
			"Misc.Mount.Flying", "Ability_Mount_Wyvern_01", "Misc.Mount.Flying")
	AutoBar_Category_Info["MOUNTS_FLYING"]:SetNonCombat(true)
	AutoBar_Category_Info["MOUNTS_FLYING"]:SetArrangeOnUse(true)

--	AutoBar_Category_Info["REJUVENATION_POTIONS"]["limit"] = { ["downhp"] = {}, ["downmana"] = {},  }
--	AutoBar_Category_Info["REJUVENATION_POTIONS"]["items"] = self:GetSetItemsArrayPT3("Consumable.Potion.Recovery.Rejuvenation",
--			AutoBar_Category_Info["REJUVENATION_POTIONS"]["limit"]["downhp"],
--			AutoBar_Category_Info["REJUVENATION_POTIONS"]["limit"]["downmana"],
--			1.1);
--	["REJUVENATION_POTIONS"] = {
--		["description"] = Consumable.Potion.Recovery.Rejuvenation;
--		["texture"] = "INV_Potion_47";
--	},
	AutoBar_Category_Info["REJUVENATION_POTIONS"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Rejuvenation", "INV_Potion_47", "Consumable.Potion.Recovery.Rejuvenation")

--	AutoBar_Category_Info["STONE_STATUES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Jeweler.Statue");
--	["STONE_STATUES"] = {
--		["description"] = Consumable.Jeweler.Statue;
--		["texture"] = "INV_Misc_Statue_10";
--	},
	AutoBar_Category_Info["STONE_STATUES"] = AutoBarItems:new(
			"Consumable.Jeweler.Statue", "INV_Misc_Statue_10", "Consumable.Jeweler.Statue")

--	AutoBar_Category_Info["DREAMLESS_SLEEP"]["items"] = self:GetSetItemsArrayPT3("Consumable.Potion.Recovery.Dreamless Sleep");
--	["DREAMLESS_SLEEP"] = {
--		["description"] = Consumable.Potion.Recovery.Dreamless Sleep;
--		["texture"] = "INV_Potion_83";
--	},
	AutoBar_Category_Info["DREAMLESS_SLEEP"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Dreamless Sleep", "INV_Potion_83", "Consumable.Potion.Recovery.Dreamless Sleep")

--	AutoBar_Category_Info["MANASTONE"]["items"] = self:GetSetItemsArrayPT3("Consumable.Mage.Mana Stone");
--	["MANASTONE"] = {
--		["description"] = Consumable.Mage.Mana Stone;
--		["texture"] = "INV_Misc_Gem_Emerald_01";
--	},
	AutoBar_Category_Info["MANASTONE"] = AutoBarItems:new(
			"Consumable.Mage.Mana Stone", "INV_Misc_Gem_Emerald_01", "Consumable.Mage.Mana Stone")

--	AutoBar_Category_Info["RAGEPOTIONS"]["items"] = self:GetSetItemsArrayPT3("Consumable.Buff.Rage.Self");
--	["RAGEPOTIONS"] = {
--		["description"] = Consumable.Buff.Rage.Self;
--		["texture"] = "INV_Potion_24";
--	},
	AutoBar_Category_Info["RAGEPOTIONS"] = AutoBarItems:new(
			"Consumable.Buff.Rage.Self", "INV_Potion_24", "Consumable.Buff.Rage.Self")

--	["ENERGYPOTIONS"] = {
--		["description"] = Consumable.Buff.Energy.Self;
--		["texture"] = "INV_Drink_Milk_05";
--		["items"] = { 7676 },
--	},
	AutoBar_Category_Info["ENERGYPOTIONS"] = AutoBarItems:new(
			"Consumable.Buff.Energy.Self", "INV_Drink_Milk_05", "Consumable.Buff.Energy.Self")

--	["BOOZE"] = {
--		["description"] = Misc.Booze;
--		["texture"] = "INV_Drink_03";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["BOOZE"] = AutoBarItems:new(
			"Misc.Booze", "INV_Drink_03", "Misc.Booze")
	AutoBar_Category_Info["BOOZE"]:SetNonCombat(true)

--	rawList = self:RawItemsAdd(nil, "Consumable.Water.Basic", false);
--	rawList = self:RawItemsAdd(rawList, "Consumable.Water.Conjured", true);
--	AutoBar_Category_Info["WATER"]["items"] = self:RawItemsConvert(rawList);
--	["WATER"] = {
--		["description"] = Consumable.Water.Basic;
--		["texture"] = "INV_Drink_10";
--		["nonCombat"] = true,
--		["castList"] = {"MAGE", BS["Conjure Water"],},
--	},
	AutoBar_Category_Info["WATER"] = AutoBarItems:new(
			"Consumable.Water.Basic", "INV_Drink_10", "Consumable.Water.Basic", "Consumable.Water.Conjured")
	AutoBar_Category_Info["WATER"]:SetNonCombat(true)
	AutoBar_Category_Info["WATER"]:SetCastList({"MAGE", BS["Conjure Water"],})

--	["WATER_PERCENT"] = {
--		["description"] = Consumable.Water.Percentage; Consumable.Water.Percentage
--		["texture"] = "INV_Drink_04";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["WATER_PERCENT"] = AutoBarItems:new(
			"Consumable.Water.Percentage", "INV_Drink_04", "Consumable.Water.Percentage")
	AutoBar_Category_Info["WATER_PERCENT"]:SetNonCombat(true)

--	AutoBar_Category_Info["WATER_SPIRIT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Water.Buff.Spirit");
--	["WATER_SPIRIT"] = {
--		["description"] = Consumable.Water.Buff.Spirit;
--		["texture"] = "INV_Drink_16";
--		["nonCombat"] = true,
--	},
	AutoBar_Category_Info["WATER_SPIRIT"] = AutoBarItems:new(
			"Consumable.Water.Buff.Spirit", "INV_Drink_16", "Consumable.Water.Buff.Spirit")
	AutoBar_Category_Info["WATER_SPIRIT"]:SetNonCombat(true)


	AutoBar_Category_Info["OIL_MANA"] = AutoBarItems:new("Consumable.Weapon Buff.Oil.Mana", "INV_Potion_100",
			"Consumable.Weapon Buff.Oil.Mana")
	AutoBar_Category_Info["OIL_MANA"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["OIL_WIZARD"] = AutoBarItems:new("Consumable.Weapon Buff.Oil.Wizard", "INV_Potion_105",
			"Consumable.Weapon Buff.Oil.Wizard")
	AutoBar_Category_Info["OIL_WIZARD"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-CRIPPLING"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Crippling", "INV_Potion_19",
			"Consumable.Weapon Buff.Poison.Crippling")
	AutoBar_Category_Info["POISON-CRIPPLING"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-DEADLY"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Deadly", "Ability_Rogue_DualWeild",
			"Consumable.Weapon Buff.Poison.Deadly")
	AutoBar_Category_Info["POISON-DEADLY"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-INSTANT"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Instant", "Ability_Poisons",
			"Consumable.Weapon Buff.Poison.Instant", "Consumable.Weapon Buff.Poison.Anesthetic")
	AutoBar_Category_Info["POISON-INSTANT"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-MINDNUMBING"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Mind Numbing", "Spell_Nature_NullifyDisease",
			"Consumable.Weapon Buff.Poison.Mind Numbing")
	AutoBar_Category_Info["POISON-MINDNUMBING"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-WOUND"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Wound", "Ability_PoisonSting",
			"Consumable.Weapon Buff.Poison.Wound")
	AutoBar_Category_Info["POISON-WOUND"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["SHARPENINGSTONES"] = AutoBarItems:new("Consumable.Weapon Buff.Stone.Sharpening Stone", "INV_Stone_SharpeningStone_01",
			"Consumable.Weapon Buff.Stone.Sharpening Stone")
	AutoBar_Category_Info["SHARPENINGSTONES"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["WEIGHTSTONES"] = AutoBarItems:new("Consumable.Weapon Buff.Stone.Weight Stone", "INV_Stone_WeightStone_02",
			"Consumable.Weapon Buff.Stone.Weight Stone")
	AutoBar_Category_Info["WEIGHTSTONES"]:SetTargetted("WEAPON")


	AutoBar_Category_Info["BUFF_GENERAL"] = AutoBarItems:new("Consumable.Buff Group.General.Self", "INV_Potion_80",
			"Consumable.Buff Group.General.Self")

	AutoBar_Category_Info["BUFF_GENERAL_TARGET"] = AutoBarItems:new("Consumable.Buff Group.General.Target", "INV_Potion_80",
			"Consumable.Buff Group.General.Target")
	AutoBar_Category_Info["BUFF_GENERAL_TARGET"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_CASTER"] = AutoBarItems:new("Consumable.Buff Group.Caster.Self", "INV_Potion_66",
			"Consumable.Buff Group.Caster.Self")

	AutoBar_Category_Info["BUFF_CASTER_TARGET"] = AutoBarItems:new("Consumable.Buff Group.Caster.Target", "INV_Potion_66",
			"Consumable.Buff Group.Caster.Target")
	AutoBar_Category_Info["BUFF_CASTER_TARGET"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_MELEE"] = AutoBarItems:new("Consumable.Buff Group.Melee.Self", "INV_Potion_43",
			"Consumable.Buff Group.Melee.Self")

	AutoBar_Category_Info["BUFF_MELEE_TARGET"] = AutoBarItems:new("Consumable.Buff Group.Melee.Target", "INV_Potion_43",
			"Consumable.Buff Group.Melee.Target")
	AutoBar_Category_Info["BUFF_MELEE_TARGET"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_OTHER"] = AutoBarItems:new("Consumable.Buff.Other.Self", "INV_Potion_80",
			"Consumable.Buff.Other.Self")

	AutoBar_Category_Info["BUFF_OTHER_TARGET"] = AutoBarItems:new("Consumable.Buff.Other.Target", "INV_Potion_80",
			"Consumable.Buff.Other.Target")
	AutoBar_Category_Info["BUFF_OTHER_TARGET"]:SetTargetted(true)


	AutoBar_Category_Info["BUFF_CHEST"] = AutoBarItems:new("Consumable.Buff.Chest", "INV_Misc_Rune_10",
			"Consumable.Buff.Chest")
	AutoBar_Category_Info["BUFF_CHEST"]:SetTargetted("CHEST")

	AutoBar_Category_Info["BUFF_SHIELD"] = AutoBarItems:new("Consumable.Buff.Shield", "INV_Misc_Rune_13",
			"Consumable.Buff.Shield")
	AutoBar_Category_Info["BUFF_SHIELD"]:SetTargetted("SHIELD")

	AutoBar_Category_Info["BUFF_WEAPON"] = AutoBarItems:new("Consumable.Weapon Buff", "INV_Misc_Rune_13",
			"Consumable.Weapon Buff")
	AutoBar_Category_Info["BUFF_WEAPON"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["BUFF_HEALTH"] = AutoBarItems:new("Consumable.Buff.Health", "INV_Potion_43",
			"Consumable.Buff.Health")

	AutoBar_Category_Info["BUFF_ARMOR"] = AutoBarItems:new("Consumable.Buff.Armor", "INV_Potion_66",
			"Consumable.Buff.Armor")

	AutoBar_Category_Info["BUFF_REGENHEALTH"] = AutoBarItems:new("Consumable.Buff.Regen Health", "INV_Potion_80",
			"Consumable.Buff.Regen Health")

	AutoBar_Category_Info["BUFF_AGILITY"] = AutoBarItems:new("Consumable.Buff.Agility", "INV_Scroll_02",
			"Consumable.Buff.Agility")
	AutoBar_Category_Info["BUFF_AGILITY"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_INTELLECT"] = AutoBarItems:new("Consumable.Buff.Intellect", "INV_Scroll_01",
			"Consumable.Buff.Intellect")
	AutoBar_Category_Info["BUFF_INTELLECT"]:SetTargetted(true)

--	AutoBar_Category_Info["BUFF_PROTECTION"] = AutoBarItems:new("Consumable.Buff.Protection", "INV_Scroll_07",
--			"Consumable.Buff.Protection")
--	AutoBar_Category_Info["BUFF_PROTECTION"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_SPIRIT"] = AutoBarItems:new("Consumable.Buff.Spirit", "INV_Scroll_01",
			"Consumable.Buff.Spirit")
	AutoBar_Category_Info["BUFF_SPIRIT"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_STAMINA"] = AutoBarItems:new("Consumable.Buff.Stamina", "INV_Scroll_07",
			"Consumable.Buff.Stamina")
	AutoBar_Category_Info["BUFF_STAMINA"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_STRENGTH"] = AutoBarItems:new("Consumable.Buff.Strength", "INV_Scroll_02",
			"Consumable.Buff.Strength")
	AutoBar_Category_Info["BUFF_STRENGTH"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_ATTACKPOWER"] = AutoBarItems:new("Consumable.Buff.Attack Power", "INV_Misc_MonsterScales_07",
			"Consumable.Buff.Attack Power")
	AutoBar_Category_Info["BUFF_ATTACKPOWER"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_ATTACKSPEED"] = AutoBarItems:new("Consumable.Buff.Attack Speed", "INV_Misc_MonsterScales_17",
			"Consumable.Buff.Attack Speed")
	AutoBar_Category_Info["BUFF_ATTACKSPEED"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_DODGE"] = AutoBarItems:new("Consumable.Buff.Dodge", "INV_Misc_MonsterScales_17",
			"Consumable.Buff.Dodge")
	AutoBar_Category_Info["BUFF_DODGE"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_RESISTANCE"] = AutoBarItems:new("Consumable.Buff.Resistance", "INV_Misc_MonsterScales_15",
			"Consumable.Buff.Resistance.Self")

	AutoBar_Category_Info["BUFF_RESISTANCE_TARGET"] = AutoBarItems:new("Consumable.Buff.Resistance", "INV_Misc_MonsterScales_15",
			"Consumable.Buff.Resistance.Target")
	AutoBar_Category_Info["BUFF_RESISTANCE_TARGET"]:SetTargetted(true)

--	["Consumable.Buff.Speed"] = {
--		["description"] = Consumable.Buff.Speed;
--		["texture"] = "INV_Potion_95";
--		["items"] = { 20081, 2459, },
--	},
	AutoBar_Category_Info["Consumable.Buff.Speed"] = AutoBarItems:new("Consumable.Buff.Speed", "INV_Potion_95",
			"Consumable.Buff.Speed")

	AutoBar_Category_Info["QUEST_ITEMS"] = AutoBarItems:new("Consumable.Quest.Usable", "INV_BannerPVP_02",
			"Consumable.Quest.Usable")
	AutoBar_Category_Info["QUEST_ITEMS"]:SetArrangeOnUse(true)
end



--AutoBar_Category_Info = {
--	["CUSTOM"] = {
--		["description"] = AUTOBAR_CLASS_CUSTOM;
--		["texture"] = "INV_Misc_Bandage_12",
--		["custom"] = true;
--		["items"] = { 19307 },
--	},
--	["AAACLEAR"] = {
--		["description"] = AUTOBAR_CLASS_CLEAR;
--		["texture"] = "INV_Misc_Fork&Knife";
--		["items"] = {},
--	},
--	----------------
--	["HEALTHSTONE_CONJURE"] = {
--		["description"] = Consumable.Warlock.Create Healthstone,
--		["texture"] = BS:GetShortSpellIcon("Create Healthstone"),
--		["spell"] = true,
--		["castList"] = {"WARLOCK", BS["Create Healthstone"]};
--	},
--	["MANASTONE_CONJURE"] = {
--		["description"] = Consumable.Mage.Conjure Mana Stone;
--		["texture"] = "INV_Misc_Gem_Emerald_01";
--	},
--	----------------
--	----------------
--	----------------
--	----------------
--	["PORTALS"] = {
--		["description"] = AUTOBAR_CLASS_PORTALS;
--		["texture"] = "Spell_Arcane_PortalShattrath";
--		["spell"] = true,
--	},
--	----------------
--	--------------
--	--------------
--	--------------
--	--------------
--	["FOOD_CONJURE"] = {
--		["description"] = Consumable.Food.Edible.Basic.Non-Conjured_CONJURE,
--		["texture"] = BS:GetShortSpellIcon("Conjure Food"),
--		["spell"] = true,
--	},
--	["WATER_CONJURE"] = {
--		["description"] = AUTOBAR_CLASS_WATER_CONJURE,
--		["texture"] = BS:GetShortSpellIcon("Conjure Water"),
--		["spell"] = true,
--	},
--	--------------
--	--------------
--	["MOUNTS_SUMMONED"] = {
--		["description"] = Misc.Mount.Summoned;
--		["texture"] = "Ability_Mount_JungleTiger";
--		["nonCombat"] = true,
--		["arrangeOnUse"] = true,
--		["spell"] = true,
--		["castList"] = {"PALADIN", BS["Summon Warhorse"], "PALADIN", BS["Summon Charger"], "WARLOCK", BS["Summon Felsteed"], "WARLOCK", BS["Summon Dreadsteed"], "DRUID", BS["Travel Form"], "DRUID", BS["Flight Form"], "DRUID", BS["Swift Flight Form"], "SHAMAN", BS["Ghost Wolf"],},
--	},
--	AutoBar_Category_Info[""]:SetArrangeOnUse(true)
--	--------------
--};

-- /dump AutoBar_Category_Info["MOUNTS_SUMMONED"]
